import React, { useState } from "react";


// Dropdown Item Component
const DropdownItem = ({
  label,
  href,
  onClick,
}: {
  label: string;
  href?: string;
  onClick?: () => void;
}) => (
  <a
    href={href || "#"}
    className="dropdown-item"
    onClick={(e) => {
      e.preventDefault();
      onClick?.();
    }}
  >
    {label}
  </a>
);

// Nested Dropdown Component
const NestedDropdown = ({
  label,
  children,
}: {
  label: string;
  children: React.ReactNode;
}) => {
  const [open, setOpen] = useState(false);

  return (
    <div className="nested-dropdown">
      {/* Dropdown Trigger */}
      <div
        className="dropdown-trigger"
        onClick={() => setOpen(!open)} // Toggle submenu on click
      >
        {label} <span className="icon">{open ? "▼" : "▶"}</span>
      </div>

      {/* Submenu */}
      {open && <div className="submenu">{children}</div>}
    </div>
  );
};

// Recursive Function to Render Nested Data
const renderNestedData = (data: Record<string, any>) => {
  return Object.entries(data).map(([key, value]) => {
    if (typeof value === "object" && !Array.isArray(value)) {
      // If the value is an object, render it as a nested dropdown
      return (
        <NestedDropdown key={key} label={key}>
          {renderNestedData(value)}
        </NestedDropdown>
      );
    } else if (Array.isArray(value)) {
      // If the value is an array, render each item as a dropdown item
      return value.map((item, index) => (
        <DropdownItem key={index} label={item} />
      ));
    } else {
      // If the value is a simple string, render it as a dropdown item
      return <DropdownItem key={key} label={value} />;
    }
  });
};

// Main Multi-Level Dropdown Component
const MultiLevelDropdown = ({ data }: { data: Record<string, any> }) => {
  const [open, setOpen] = useState(false);

  return (
    <div className="multi-level-dropdown">
      {/* Dropdown Trigger Button */}
      <button
        className="dropdown-button"
        onClick={() => setOpen(!open)} // Toggle main menu on click
      >
        Dropdown trigger <span className="icon">▼</span>
      </button>

      {/* Dropdown Menu */}
      {open && <div className="dropdown-menu">{renderNestedData(data)}</div>}
    </div>
  );
};

export default MultiLevelDropdown;